##  Synchronizing Other Fact Sheets
For dictionary items other than applications, for instance, initiatives or business capabilities:
  * A relationship between an object and a business context fact sheet is created only if the corresponding dictionary item is directly linked to the process template.
  * As variant-specific items don’t provide a standalone value for enterprise architecture purposes, dictionary items linked only to process variants are not synchronized, and no relations are created for them in SAP LeanIX.
